using Model;
using Model.Stub;
using System.Collections.ObjectModel;

namespace Linaris;

public partial class PlaylistsPage : ContentPage
{

    private ObservableCollection<Playlist> playlists = (Application.Current as App).Manager.GetPlaylists();

    public ObservableCollection<Playlist> Playlists
    {
        get => playlists;
    }

    private bool isNewPlaylist = false;

    public bool IsNewPlaylist
    {
        get => isNewPlaylist;
        set
        {
            isNewPlaylist = value;
            OnPropertyChanged(nameof(IsNewPlaylist));
        }
    }

    public PlaylistsPage()
	{
		InitializeComponent();
        BindingContext = this;
    }

    // Reset methods

    void ResetAll(object sender, EventArgs e)
    {
        ResetSubMenus(sender, e);
        IsNewPlaylist = false;
    }

    void ResetSubMenus(object sender, EventArgs e)
    {
        foreach (var Playlist in playlists)
        {
            Playlist.IsSubMenuVisible = false;
        }
    }


    // Add methods

    void CreatePlaylist(object sender, EventArgs e)
    {
        if (sender is Entry entry)
        {
            if (!HasSameName(entry.Text))
            {
                Playlist playlist = new Playlist(entry.Text, "", "none.png");
                (Application.Current as App).Manager.AddPlaylist(playlist);
                playlists.Add(playlist);
                IsNewPlaylist = false;
                entry.Text = "";
            }
        }
    }


    // Remove methods

    void RemovePlaylist(object sender, EventArgs e)
    {
        if (sender is Button button)
        {
            if (button.BindingContext is Playlist playlist)
            {
                (Application.Current as App).Manager.RemovePlaylist(playlist);
                playlists.Remove(playlist);
            }
        }
    }


    // Show methods

    void ShowSubMenu(object sender, EventArgs e)
    {
        if (sender is Image image)
        {
            if (image.BindingContext is Playlist playlist)
            {
                if (!playlist.IsSubMenuVisible)
                {
                    ResetAll(sender, e);
                    playlist.IsSubMenuVisible = true;
                }
                else
                {
                    ResetSubMenus(sender, e);
                }
            }
        }
    }

    void ShowEntryPlaylist(object sender, EventArgs e)
    {
        IsNewPlaylist = true;
    }


    // Change methods

    private async void ChangeImage(object sender, EventArgs e)
    {
        var result = await FilePicker.PickAsync(new PickOptions
        {
            PickerTitle = "Choisissez une nouvelle image !",
            FileTypes = FilePickerFileType.Images
        });

        if (result == null)
        {
            return;
        }

        if (sender is Button button)
        {
            if (button.BindingContext is Playlist playlist)
            {
                playlist.ImageURL = result.FullPath;
            }
        }
    }

    // Search methods

    bool HasSameName(string name)
    {
        foreach(Playlist playlist in playlists)
        {
            if (playlist.Name == name)
            {
                return true;
            }
        }
        return false;
    }

    // Navigation

    async void GoToPlaylist(object sender, EventArgs e)
    {
        await Navigation.PushAsync(new PlaylistPage());
    }
}